package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.UserBindingConfig;

/**
 * 合伙人绑定页面配置Service接口
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
public interface IUserBindingConfigService 
{
    /**
     * 查询合伙人绑定页面配置
     * 
     * @param id 合伙人绑定页面配置主键
     * @return 合伙人绑定页面配置
     */
    public UserBindingConfig selectUserBindingConfigById(Long id);

    /**
     * 查询合伙人绑定页面配置列表
     * 
     * @param userBindingConfig 合伙人绑定页面配置
     * @return 合伙人绑定页面配置集合
     */
    public List<UserBindingConfig> selectUserBindingConfigList(UserBindingConfig userBindingConfig);

    /**
     * 新增合伙人绑定页面配置
     * 
     * @param userBindingConfig 合伙人绑定页面配置
     * @return 结果
     */
    public int insertUserBindingConfig(UserBindingConfig userBindingConfig);

    /**
     * 修改合伙人绑定页面配置
     * 
     * @param userBindingConfig 合伙人绑定页面配置
     * @return 结果
     */
    public int updateUserBindingConfig(UserBindingConfig userBindingConfig);

    /**
     * 批量删除合伙人绑定页面配置
     * 
     * @param ids 需要删除的合伙人绑定页面配置主键集合
     * @return 结果
     */
    public int deleteUserBindingConfigByIds(Long[] ids);

    /**
     * 删除合伙人绑定页面配置信息
     * 
     * @param id 合伙人绑定页面配置主键
     * @return 结果
     */
    public int deleteUserBindingConfigById(Long id);
}
